﻿#region Using directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Windows.Forms;

#endregion
using Microsoft.AnalysisServices.AdomdClient;
namespace AdomdIterateDatabases
{
	partial class AdomdIterateDatabasesForm : Form
	{
		private AdomdConnection con = new AdomdConnection();
		private Boolean	areDatabasesPopulated = false;

		// This function produces a list of names of the existing databases
		// on the server whose name was entered by the user in serverBox TextBox.
		private void PopulateDatabases()
		{
			if (areDatabasesPopulated)
				return;
			//if connection is already open, close it.
			if (con.State == ConnectionState.Open)
				con.Close();

			// Open the connection
			con.ConnectionString = "Datasource=" + serverBox.Text;
			try
			{
				if (con.State != ConnectionState.Open)
                    con.Open();
				databaseBox.Enabled = true;
                databaseBox.Items.Clear();
                //Retrieve DataSet that contains all the databases.
				DataSet catalogs = con.GetSchemaDataSet("DBSCHEMA_CATALOGS", null);
				//All the results will be located in the first table of the dataset.
				//Populate the combo box with the names of the databases.
				foreach (DataRow row in catalogs.Tables[0].Rows)
				{
					databaseBox.Items.Add(row["CATALOG_NAME"]);
				}
				areDatabasesPopulated = true;
				return;
			}
			catch (AdomdConnectionException conException)
			{
				// If there was a connection error, pass it to the user.				
				MessageBox.Show(conException.Message,"Connection Error");
			}
			catch (AdomdErrorResponseException errException)
			{
                //If there was an error in the request, pass it to the user.
                MessageBox.Show(errException.Message, "Error Response");
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message, "Error");
			}
		}

		public AdomdIterateDatabasesForm()
		{
			InitializeComponent();
		}

        //This method will be called when the user selects a database from the combo box.
		private void databaseBox_SelectedIndexChanged(object sender, EventArgs e)
		{
			// The user has chosen one database
			// Change the current database to the database chosen by the user 
			ComboBox comboBox = (ComboBox)sender;
			string selectedDatabase = (string)comboBox.SelectedItem;
            if ( null!=selectedDatabase )
			    con.ChangeDatabase(selectedDatabase);
		}

		//This method will be called when the user expands a combo box.
		private void databaseBox_DropDown(object sender, System.EventArgs e)
		{
			// Call the function to make a list of all the databases.
			PopulateDatabases();
		}

		private void serverBox_TextChanged(object sender, EventArgs e)
		{
			// If the user chose a different server name, the list of databases should be repopulated
			areDatabasesPopulated = false;
		}

        private void AdomdIterateDatabasesForm_Load(object sender, EventArgs e)
        {

        }

	}
}