using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.AnalysisServices.AdomdClient;
using System.Data;

namespace AdomdNestedRowsetSample
{
	class Program
	{
		static void Main(string[] args)
		{
			WriteDiscoverSchemaRowsets();
		}

		static public void WriteDiscoverSchemaRowsets()
		{
			//Open a connection to the server
			AdomdConnection con = new AdomdConnection();
			con.ConnectionString = "Datasource=localhost; Initial Catalog=Foodmart 2005;";
			con.Open();

			//Create a restriction collection that will limit the result to information about the Actions schema rowset
			AdomdRestrictionCollection restrictions = new AdomdRestrictionCollection();
			restrictions.Add("SchemaName", "MDSCHEMA_ACTIONS");

			//Call the method GetSchemaDataSet
			DataSet ds = con.GetSchemaDataSet("DISCOVER_SCHEMA_ROWSETS", restrictions);

			//Get the first table. ADOMD.NET will always return it even if the result is empty.
			DataTable dt = ds.Tables[0];

			//To improve performance, we will create an array in which we will store DataRelation for each column that contains DataRelation and null if the column contains data values
			DataRelation[] drMap = new DataRelation[dt.Columns.Count];
			int iColumn = 0;
			//Iterate all the columns and relationships in the DataTable
			//This is certainly not very convenient. It would be better if the column stored additional information whether it contains reference or data. But unfortunately thats not the way it works.
			foreach(DataColumn column in dt.Columns)
			{
				foreach (DataRelation dataRelation in ds.Relations)
				{
					if (IsParentRelationColumn(dataRelation, column))
					{
							drMap[iColumn] = dataRelation;
							break;
						}
				}
				iColumn ++;
			}
     
			//Iterate the rows of the first datatable and print their values
			foreach (DataRow row in dt.Rows)
			{
				iColumn = 0;
				foreach(DataColumn column in dt.Columns)
				{
					if (drMap[iColumn]!= null)
					{
							Console.WriteLine(column.ColumnName);
							//Navigate to the nested table through relationship
							foreach(DataRow childRow in row.GetChildRows(drMap[iColumn]))
							{
								foreach(DataColumn childColumn in childRow.Table.Columns)
								{
									//If the column is a data column rather than a relationship column, print data value
									if (! IsChildRelationColumn(drMap[iColumn], childColumn))
									{
											object field = childRow[childColumn];
											Console.WriteLine(" " + childColumn.Caption + "=" + field.ToString ());
											}
									}
							}
					}
					else
					{
							object field = row [column];
							Console.WriteLine(column.Caption + "=" + field.ToString());
						}
						iColumn++;
				}
			}
			//Close the connection
			con.Close();
		}
		//The helper function that detects whether the column is a child of the Relation
		static private bool IsChildRelationColumn(DataRelation dataRelation, DataColumn dataColumn)
		{
			foreach (DataColumn relationColumn in dataRelation.ChildColumns)
			{
				if (dataColumn == relationColumn)
				{
					return true;
				}
			}
			return false;
		}

		//The helper function that detects whether a column is a child of a relation
		static private bool IsParentRelationColumn(DataRelation dataRelation, DataColumn dataColumn)
		{
			foreach (DataColumn relationColumn in dataRelation.ParentColumns)
			{
				if (dataColumn == relationColumn)
				{
					return true;
				}
			}
			return false;
		}

	}
}
