﻿#region Using directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Windows.Forms;

#endregion
using Microsoft.AnalysisServices.AdomdClient;

namespace AdomdParametricQuery
{
	partial class Form1 : Form
	{
		private AdomdConnection con = new AdomdConnection();
		private TupleCollection productFamiliesTuples = null;

		public Form1()
		{
			InitializeComponent();
			// During initialization of the form, we create a connection to the server
			this.con.ConnectionString = "Datasource=localhost;Initial Catalog=Foodmart 2005";
			this.con.Open();
			//Fill out the combo box with all the product families
			PopulateProductFamilies();
		}

	    // When the user clicks the Execute button, the MDX query to request the best selling product is sent, using the Product Family that the user chose and the expected number of products, also chosen by the user
		private void Execute_Click(object sender, EventArgs e)
		{
			//Create the command object
			AdomdCommand command = this.con.CreateCommand();
			//Make sure that the MDX request contains special labels for the parameters
            command.CommandText = "SELECT topcount(Descendants(StrToMember(@productFamilyMember, CONSTRAINED), [Product].[Products].[Product] ), @topCount, [Measures].[Unit Sales] ) ON COLUMNS FROM [Warehouse and Sales]";
			// The product family chosen by the user.
			// Find the unique name of the tuple that represent the Product Family the user chose in the first request
			string choosenProductFamily = this.productFamiliesTuples[productFamiliesBox1.SelectedIndex].Members[0].UniqueName;
			//Create parameters 
			command.Parameters.Add("productFamilyMember", choosenProductFamily);
			command.Parameters.Add("TopCount", topCountBox.Value);
			//Send the request
			CellSet topProductsCellSet = command.ExecuteCellSet();
            topProductsBox1.Items.Clear();
            //Fill out the list box with the products returned by this MDX request.
			foreach (Tuple tuple in topProductsCellSet.Axes[0].Set.Tuples)
			{
				topProductsBox1.Items.Add(tuple.Members[0].Caption);
			}
		}

		//Fill in the combo box with all the possible product families. 
        //In order to do this, generate the following MDX request to send to the server:
        //SELECT  [Product].[Products].[Product Family].members ON COLUMNS FROM [Warehouse and Sales]
		private 	void		PopulateProductFamilies()
		{
			AdomdCommand command = this.con.CreateCommand();
            command.CommandText = "SELECT  [Product].[Products].[Product Family].members ON COLUMNS FROM [Warehouse and Sales]";
			CellSet cellSet = command.ExecuteCellSet();
			productFamiliesTuples = cellSet.Axes[0].Set.Tuples;
			foreach (Tuple tuple in productFamiliesTuples)
			{
				productFamiliesBox1.Items.Add(tuple.Members[0].Caption);
			}
			productFamiliesBox1.SelectedIndex = 0;
			return;
		}

        private void Form1_Load(object sender, EventArgs e)
        {

        }


	}
}